/*
 * Copyright (C) 2005-2010 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.service.cmr.dictionary;

import java.util.Collection;
import java.util.Date;

import org.alfresco.service.namespace.QName;


/**
 * Read-only definition of a Model.
 * 
 * @author David Caruana
 */
public interface ModelDefinition
{
    /**
     * @return the model name
     */
    public QName getName();
    
    /**
     * @return the model description
     */
    public String getDescription();
    
    /**
     * @return the model author
     */
    public String getAuthor();
    
    /**
     * @return the date when the model was published
     */
    public Date getPublishedDate();
    
    /**
     * @return the model version
     */
    public String getVersion();
    
    /**
     * @return  the namespaces defined by this model
     */
    public Collection<NamespaceDefinition> getNamespaces();

    /**
     * @param uri  namespace uri
     * @return  true => model defines the uri
     */
    public boolean isNamespaceDefined(String uri);
    
    /**
     * @return  the namespaces imported by this model
     */
    public Collection<NamespaceDefinition> getImportedNamespaces();
    
    /**
     * @param uri  namespace uri
     * @return  true => model imports the uri
     */
    public boolean isNamespaceImported(String uri);
}
